@@ -738,7 +738,7 @@ def resize(im: np.ndarray, sz: [float, ("H", "W"), (str, ("H", "W"))]):
         >>> _im = resize(im, ('at-least',(400,40))) ; assert _im.shape == (400,800) #*
         >>> _im = resize(im, ('at-most', (40,400))) ; assert _im.shape == (40,80)   #*
         >>> _im = resize(im, ('at-most', (400,40))) ; assert _im.shape == (20,40)   #*
-   """
+    """
     h, w = im.shape[:2]
     if isinstance(sz, (tuple, list)) and isinstance(sz[0], str):
         signal, (H, W) = sz
@@ -783,7 +783,7 @@ def pad(im, sz, pad_value=255):
 def xywh2xyXY(bbs):
     if len(bbs) == 4 and isinstance(bbs[0], int):
         x, y, w, h = bbs
-        return BBox(x, y, x + w, y + h)
+        return BB(x, y, x + w, y + h)
     return [xywh2xyXY(bb) for bb in bbs]
 
 
@@ -908,4 +908,3 @@ def shrink_bbs(bbs, eps=0.2):
         BB(x + (w * epsx), y + (h * epsy), X - (w * epsX), Y - (h * epsY))
         for (x, y, X, Y), (h, w) in zip(bbs, shs)
     ]
-
